# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import random

from entrypoint.common.db import dbConnect

class Key:
    def __init__(self, **kwargs):
        if 'db' in kwargs:
	        self.db = kwargs['db']
        else:
            self.db = dbConnect()
        
        if 'key' in kwargs:
            self.key = kwargs['key']
            self.db.execute("SELECT `type`, `type_id` FROM `keys` WHERE `key` = %s", (self.key))
            keyData = self.db.fetchone()
            if keyData == None:
                self.keyType = None
                self.keyTypeId = None
            else:
                (self.keyType, self.keyTypeId) = keyData
        elif 'KeyType' in kwargs and 'keyTypeId' and 'get' in kwargs:
            self.keyType = kwargs['KeyType']
            self.keyTypeId = kwargs['keyTypeId']
            self.db.execute("SELECT `key` FROM `keys` WHERE `type` = %s AND `type_id` = %s", (self.keyType, self.keyTypeId))
            keyData = self.db.fetchone()
            if keyData == None:
                self.key = None
            else:
                self.key = keyData[0]
            
            
        elif 'KeyType' in kwargs and 'keyTypeId' in kwargs:
            self.key = self._generate_key()
            self.keyType = kwargs['KeyType']
            self.keyTypeId = kwargs['keyTypeId']
            self._create()
            
    def _generate_key(self):
        used = 1
        while used != None:
            key = str(random.randint(100, 999)) + str(random.randint(100, 999))
            self.db.execute("SELECT `type_id` FROM `keys` WHERE `key` = %s", (key))
            used = self.db.fetchone()
                
        return key
        
    def _create(self):
        self.db.execute("INSERT INTO `keys` (`key`, `type`, `type_id`) VALUES (%s, %s, %s);", (self.key, self.keyType, self.keyTypeId))
        self.db.commit()
        
    def get_key(self):
        # returns key
        return self.key
        
    def get_key_type(self):
        # returns object id that the key is related to.
        return self.keyTypeId
        
    def get_key_type(self): 
        # returns key type.
        return self.keyType
        
    def delete(self):
        # Delete the key
        self.db.execute("DELETE FROM `keys` WHERE `key` = %s", (self.key))
        self.db.commit()
        
    def get_related_object(self):
        if self.keyType == 'visitor':
            import entrypoint.common.Visitor
            return entrypoint.common.Visitor.Visitor(vid=self.keyTypeId)
        elif self.keyType == 'member':
            import entrypoint.common.Member
            return entrypoint.common.Member.Member(db=self.db, mid=self.keyTypeId)
