# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import StringIO
from PIL import Image
import datetime

from entrypoint.common.db import dbConnect
import entrypoint.common.Key

class Member:
    
    def __init__(self, **kwargs):
        if 'db' in kwargs:
	        self.db = kwargs['db']
        else:
            self.db = dbConnect()
        
        if 'firstName' in kwargs:
	        self.title = kwargs['title'] # string
		    self.firstName = kwargs['firstName'] # string
		    self.lastName = kwargs['lastName'] # string
		    self.dateOfBirth = kwargs['dateOfBirth'] #if 'mid' in kwargs: date
		    self.carRegistration = kwargs['carRegistration'] # string
		    self.type = kwargs['memberType'] # string
		    self.notes = kwargs['notes'] # string
		    self.active = kwargs['active'] # boolean
		    self.create()
	    
	    elif 'mid' in kwargs:
	        self.db.execute("SELECT * FROM `members` WHERE `mid`=%s", (kwargs['mid']))
	        (mid, title, firstName, lastName, dateOfBirth, carRegistration, memberType, notes, active) = self.db.fetchone()
	        self.mid = kwargs['mid']
	        self.title = title # string
		    self.firstName = firstName # string
		    self.lastName = lastName # string
		    self.dateOfBirth = dateOfBirth # date
		    self.carRegistration = carRegistration # string
		    self.type = memberType # string
		    self.notes = notes # string
		    self.active = active # boolean
		    self.key = entrypoint.common.Key.Key(KeyType='member', keyTypeId=self.mid, get=True, db=self.db).get_key()
		   
	def get_key(self):
	    return str(self.key)
	
	def get_id(self):
	    return self.mid
	
	def get_title(self):
	    # returns title
	    return str(self.title)
    
    def get_first_name(self):
        # returns first name
        return str(self.firstName)
        
    def get_last_name(self):
        # returns last name
        return str(self.lastName)
        
    def get_name(self):
        return str(self.firstName) + ' ' + str(self.lastName)
        
    def get_date_of_birth(self):
        # returns date of birth
        return self.dateOfBirth
        
    def get_car_registration(self):
        # returns car registration
        return str(self.carRegistration)
        
    def get_type(self):
        # returns type
        return self.type
        
    def get_notes(self):
        # returns notes
        return str(self.notes)
        
    def get_active(self):
        # returns active
        return self.active
        
    def get_photo(self):
        # Returns photo from database
        self.db.execute("SELECT `photo_blob` FROM `member_photo` WHERE `mid` = %s", (self.mid))
        row = self.db.fetchone()
        if row == None:
            return None
        else:
            return row[0]
            
    def get_status(self):
        # Returns if member is in or out
        # if true is returned then member is in
        self.db.execute("SELECT `mlid` FROM `member_log` WHERE `mid` = %s AND `time_out` IS NULL;", (self.mid))
        row = self.db.fetchone()
        if row == None:
            return False
        else:
            return True
            
    def get_log(self, dateFrom="", dateTo=""):
        dateFilter = ""
        if (not dateFrom == "" and not dateTo == ""):
            dateFilter = "AND date(time_in) BETWEEN '"+str(dateFrom)+" 00:00:00' AND '"+str(dateTo)+" 23:59:59'"
        
        self.db.execute("SELECT `time_in`, `time_out` FROM `member_log` WHERE `mid` = '"+str(self.mid)+"' "+str(dateFilter)+" ORDER BY `time_in` DESC;")
        return self.db.fetchall()
        
    def set_photo(self, photoPath):
        if not self.get_photo() == None:
            self.delete_photo()
            
        img = Image.open(photoPath)
        #resize image:
        width, height = img.size
        
        newHeight = height
        div = 0
        
        while newHeight > 500:
            div = div + 0.10
            newWidth = int(width / div)
            newHeight = int(height / div)
        
        img = img.convert("RGB").resize((newWidth,newHeight), Image.ANTIALIAS)
        
        photo = StringIO.StringIO()
        img.save(photo, 'png')
        photo1 = photo.getvalue()
        photo.close()
        self.db.execute ("INSERT INTO member_photo (`mid`, `photo_blob`) VALUES (%s, %s)", (self.mid, photo1))
        self.db.commit()
    
    def delete_photo(self):
        self.db.execute("DELETE FROM `member_photo` WHERE mid = %s", (self.mid))
		self.db.commit()
		
	def update(self, title, firstName, lastName, dateOfBirth, carRegistration, memberType, notes, active):
		self.db.execute("UPDATE `members` SET `title` = %s, `first_name` = %s, `last_name` = %s, `date_of_birth` = %s, `car_registration` = %s, `type` = %s, `notes` = %s, `active` = %s WHERE `mid` = %s;", (title, firstName, lastName, dateOfBirth, carRegistration, memberType, notes, active, self.mid))
		self.db.commit()
		
        self.title = title # string
        self.firstName = firstName # string
        self.lastName = lastName # string
        self.dateOfBirth = dateOfBirth # date
        self.carRegistration = carRegistration # string
        self.type = memberType # string
        self.notes = notes # string
        self.active = active # boolean

    def create(self):
		# returns
		
		self.db.execute("""INSERT INTO `members`
		                   (`title`,`first_name`,`last_name`,`date_of_birth`,`car_registration`,`type`,`notes`,`active`) VALUES
		                   (%s, %s, %s, %s, %s, %s, %s, %s);""",(self.title, self.firstName, self.lastName, self.dateOfBirth, self.carRegistration, self.type, self.notes, self.active))
        self.db.commit()
        self.mid = self.db.lastrowid()
        
        self.key = entrypoint.common.Key.Key(KeyType='member', keyTypeId=self.mid, db=self.db).get_key()
        
    def sign_in_out(self):
        if self.get_status():
            self.db.execute("UPDATE `member_log` SET `time_out` = %s WHERE `mid` = %s AND `time_out` IS NULL;", (datetime.datetime.now(), self.mid))
        else:
            self.db.execute("INSERT INTO `member_log` (`mid`, `time_in`, `time_out`) VALUES (%s, %s, NULL);", (self.mid, datetime.datetime.now()))
            
        self.db.commit()
         
