# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import re
import sys
from gi.repository import Gtk

from entrypoint.common.db import dbConnect
from entrypoint.common.Settings import Settings

class DatabaseSettingWindow(Gtk.Window):

    def __init__(self, command):
        Gtk.Window.__init__(self, title="EntryPoint Kiosk Database Settings")
        
        self.command = command
        self.connect("delete-event", Gtk.main_quit)
        
        table = Gtk.Table(5,2, False)
        self.add(table)
        table.set_col_spacings(5)
        
        hostLabel = Gtk.Label("Host:")
        self.hostEntry = Gtk.Entry()

        databaseLabel = Gtk.Label("Database:")
        self.databaseEntry = Gtk.Entry()
        self.databaseEntry.set_text("entrypoint")
        
        userLabel = Gtk.Label("Username:")
        self.userEntry = Gtk.Entry()
        
        passwordLabel = Gtk.Label("Password:")
        self.passwordEntry = Gtk.Entry()
        
        exitButton = Gtk.Button(label="Exit")
        exitButton.connect("clicked", Gtk.main_quit)
                
        button = Gtk.Button(label="Save")
        button.connect("clicked", self.on_button_clicked)

        table.attach(hostLabel, 0,1,0,1,xoptions=Gtk.AttachOptions.SHRINK)
        table.attach(self.hostEntry,1,2,0,1)
        table.attach(databaseLabel, 0,1,1,2,xoptions=Gtk.AttachOptions.SHRINK)
        table.attach(self.databaseEntry,1,2,1,2)
        table.attach(userLabel, 0,1,2,3,xoptions=Gtk.AttachOptions.SHRINK)
        table.attach(self.userEntry,1,2,2,3)
        table.attach(passwordLabel, 0,1,3,4,xoptions=Gtk.AttachOptions.SHRINK)
        table.attach(self.passwordEntry,1,2,3,4)
        table.attach(exitButton,0,1,4,5)
        table.attach(button,1,2,4,5)
        
    def on_button_clicked(self, button):
        host = self.hostEntry.get_text()
        database = self.databaseEntry.get_text()
        user = self.userEntry.get_text()
        passwd = self.passwordEntry.get_text()
        if dbConnect(host, user, passwd, database).test_connect():
            settings = Settings()
            settings.set_item("database", "host", host)
            settings.set_item("database", "database", database)
            settings.set_item("database", "user", user)
            settings.set_item("database", "password", passwd)
            settings.write()
            self.destroy()
            self.command()
            
        else:
            dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR,
            Gtk.ButtonsType.OK, "Incorrect MySQL Database Settings")
            dialog.format_secondary_text("Please ensure that the database settings are correct. If you contiune to have problems please contact support.")
            dialog.run()
            dialog.destroy()
            

