# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2011 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import cups

from reportlab.pdfgen import canvas
from reportlab.graphics.barcode import createBarcodeDrawing
from reportlab.lib.colors import white, black, HexColor
from reportlab.lib.units import mm
from reportlab.platypus import SimpleDocTemplate, Table, TableStyle
from reportlab.lib.pagesizes import A4

from entrypoint.common.Settings import Settings

def get_label_printer():
    printer = Settings().get_item('printers', 'label-printer')
    con = cups.Connection()
    if printer in con.getPrinters():
        return printer
    else:
        return False
        
def get_fire_printers():
    currentPrinters = []
    con = cups.Connection()
    settings = Settings()
    i =1
    while i < 6:
        printer = settings.get_item('printers', 'fire-printer-'+str(i))
        if printer == False:
            pass
        elif printer in con.getPrinters():
            currentPrinters.append(printer)
        i+=1
    return currentPrinters
    
def print_visitor_pass(name, company, reason, key, signInTime):
    c = canvas.Canvas("/tmp/badge.pdf", pagesize=(250,123.07))

    c.rect(0,0,250, 123.07)
    c.rect(0,100,250, 25,fill=True, stroke=False)
    c.setFont('Helvetica', 23)
    c.setFillColor(white)
    c.drawString(110,104,"Visitor Pass")
    c.setFillColor(black)
    c.setFont('Helvetica', 20)
    c.drawString(5,80, name)
    c.setFont('Helvetica', 10)
    c.drawString(5,67, company)
    c.drawString(5,56, "Reason: "+str(reason))

    c.setFont('Helvetica', 10)
    c.drawString(5,26, "Please scan this barcode to sign out")

    c.drawString(5,15, signInTime)
    c.setFont('Helvetica', 7)
    c.drawString(5,5, "Powered by EntryPoint - www.entrypoint.org.uk")

    c.setFillColor(black)
    bc = createBarcodeDrawing('Code128', value=str(key), barWidth=0.323*mm, barHeight=35, humanReadable=False)
    bc.rotate(90)
    bc.drawOn(c,245,-5)
            
    c.save()
    
    #TODO: Needs Threading so can move on to next thing
    pdf=open("/tmp/badge.pdf", "r")
    rawPdf = pdf.read()
    pdf.close()
    
    printer = get_label_printer()

    if printer == False:
        printCommand = "lpr -J 'Badge'"
    else:
        printCommand = "lpr -J 'Badge' -P '" + str(printer) + "'"
    
    pr=os.popen(printCommand, "w")
    pr.write(rawPdf)
    pr.close()
    
def print_report(data): 
    doc = SimpleDocTemplate('/tmp/report.pdf', pagesize=A4)
    (x,y) = A4
    # container for the 'Flowable' objects
    elements = []

    t=Table(data,)
    t.setStyle(TableStyle([('INNERGRID', (0,0), (-1,-1), 0.25, black),
                           ('BOX',(0,0),(-1,-1),0.25,black),
                           ('BACKGROUND', (0, 0), (5, 0), HexColor("#3366FF")),]))
     
    elements.append(t)
    # write the document to disk
    doc.build(elements)
    
    pdf=open("/tmp/report.pdf", "r")
    rawPdf = pdf.read()
    pdf.close()
    
    for printer in get_fire_printers():
        pr=os.popen("lpr -P '"+str(printer)+"' -J 'Fire Report'", "w")
        pr.write(rawPdf)
        pr.close()
    #else:
    #    pr=os.popen("lpr -J 'Fire Report'", "w")
    #    pr.write(rawPdf)
    #    pr.close()
    

