# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import Gtk

from entrypoint.kiosk.Settings import get_theme_file_path

class ListView():
    
    def __init__(self):
        self.VBox = Gtk.VBox()
        
        #Question Label
        self.label = Gtk.Label()
        self.VBox.pack_start(self.label, False, False, 0)
        
        self.HBox = Gtk.HBox()
        self.VBox.pack_start(self.HBox, True, True, 0)
        
        # List
        self.TreeView = Gtk.TreeView()
        self.selection = self.TreeView.get_selection()
        self.selection.set_mode(Gtk.SelectionMode.BROWSE)
        self.HBox.pack_start(self.TreeView, True, True, 0)
        
        # Buttons
        VBox = Gtk.VBox()
        self.HBox.pack_start(VBox, False, False, 0)
        
        buttonUp = Gtk.Button()
        buttonUp.set_property("name", "buttonUp")
        buttonUp.set_size_request(65,65)
        image = Gtk.Image()
        image.set_from_file(get_theme_file_path('icons', 'up'))
        buttonUp.add(image)
        buttonUp.connect("clicked", self.on_up_clicked)
        VBox.pack_start(buttonUp, False, False, 0)
        
        Fixed1 = Gtk.Fixed()
        VBox.pack_start(Fixed1, True, True, 0)
        
        buttonDwn = Gtk.Button()
        buttonDwn.set_property("name", "buttonDown")
        buttonDwn.set_size_request(65,65)
        image = Gtk.Image()
        image.set_from_file(get_theme_file_path('icons', 'down'))
        buttonDwn.add(image)
        buttonDwn.connect("clicked", self.on_down_clicked)
        VBox.pack_start(buttonDwn, False, False, 0)
    
    def set_list(self, *args):
        self.list = Gtk.ListStore(*args)
        self.TreeView.set_model(self.list)
        
    def set_columns(self, data):
        i = 0
        #Remove Old Columns
        for col in self.TreeView.get_columns():
            self.TreeView.remove_column(col)
            
        #Add New Columns
        for columnData in data:
            (name, visible, cType) = columnData
            if cType == 'text':
                column = Gtk.TreeViewColumn(name, Gtk.CellRendererText(), text=i)
            elif cType == 'checkbox':
                renderer_toggle = Gtk.CellRendererToggle()
                renderer_toggle.connect("toggled", self.on_cell_toggled)
                column = Gtk.TreeViewColumn(name, renderer_toggle, active=i)
                
            elif cType == 'radio':
                renderer_radio = Gtk.CellRendererToggle()
                renderer_radio.set_radio(True)
                renderer_radio.connect("toggled", self.on_cell_radio_toggled)
                column = Gtk.TreeViewColumn(name, renderer_radio, active=i)
                
            column.set_resizable(False)
            column.set_visible(visible)
            #column.set_sort_column_id(i)
            self.TreeView.append_column(column)
        
            i += 1

    def get_view(self):
        return self.VBox
        
    def set_visible(self, status):
        """Set the visible of the view"""
        self.VBox.set_visible(status)
        
    def list_append(self, data):
        self.list.append(data)
        
    def set_question(self, question):
        self.label.set_text(question)
        
    def list_clear(self):
        self.list.clear()
        
    def get_selected(self):
        return self.selection.get_selected()
        
    def on_cell_toggled(self, widget, path):
        self.list[path][0] = not self.list[path][0]
        
    def on_cell_radio_toggled(self, widget, path):
        selected_path = Gtk.TreePath(path)
        for row in self.list:
            row[0] = (row.path == selected_path)
            
    def iter_prev(self, iter, model):
        path = model.get_path(iter)
        position = path[-1]
        if position == 0:
         return None
        prev_path = list(path)[:-1]
        prev_path.append(position - 1)
        prev = model.get_iter(tuple(prev_path))
        return prev
    
    def on_up_clicked(self, widget):
        sel = self.selection.get_selected()
        if not sel[1] == None:
            next = self.list.iter_previous(sel[1])
        else:
            next = self.list.get_iter_first()
        if next:  
            self.selection.select_iter(next)
    
    def on_down_clicked(self, widget):
        sel = self.selection.get_selected()
        if not sel[1] == None:
            next = self.list.iter_next(sel[1])
        else:
            next = self.list.get_iter_first()
        if next:    
            self.selection.select_iter(next)
