# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2011 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import Gtk

from entrypoint.kiosk.Settings import get_theme_file_path
from entrypoint.common.GlobalSetting import GlobalSetting

class MainView():
    """Provides the main menu view"""
    
    def __init__(self, visitorSignInCommand, visitorSignOutCommand, staffCommand, cogCommand, fireCommand):
        """Sets up the view"""
        
        self.VBox = Gtk.VBox()
        label = Gtk.Label()
        label.set_property("name", "mainWelcome")
        #TODO: remove markup
        label.set_markup("<span weight='heavy'><big>Welcome to %s</big></span>" % (GlobalSetting().get_setting('organisationName')))
        self.VBox.pack_start(label, False, False, 0)
        
        label2 = Gtk.Label()
        label2.set_property("name", "mainWelcomeLine2")
        label2.set_text("Please scan your ID badge/label or select an option below.")
        self.VBox.pack_start(label2, False, False, 0)
        
        # Main Buttons
        HBox = Gtk.HBox()
        self.VBox.pack_start(HBox, True, True, 0)

        ## Fixed Left
        FixedLeft = Gtk.Fixed()
        HBox.pack_start(FixedLeft, True, True, 0)
        
        ## Table
        ButtonsTable = Gtk.Table(2, 3, False)
        HBox.pack_start(ButtonsTable, False, False, 0)
        
        ### Buttons
        buttonVisitorIn = Gtk.Button(label="Visitor Sign In")
        buttonVisitorIn.set_size_request(250,150)
        buttonVisitorIn.set_property('can-focus', False)
        buttonVisitorIn.connect("clicked", visitorSignInCommand)
        ButtonsTable.attach(buttonVisitorIn, 0, 1, 0, 1, False, False)
        
        buttonFixed1 = Gtk.Fixed()
        ButtonsTable.attach(buttonFixed1, 1, 2, 0, 1, False, False)
        
        buttonVisitorOut = Gtk.Button(label="Visitor Sign Out")
        buttonVisitorOut.set_size_request(250,150)
        buttonVisitorOut.set_property('can-focus', False)
        buttonVisitorOut.connect("clicked", visitorSignOutCommand)
        ButtonsTable.attach(buttonVisitorOut, 2, 3, 0, 1, False, False)
        
        buttonStaff = Gtk.Button(label="Staff/Members")
        buttonStaff.set_size_request(250,150)
        buttonStaff.set_property('can-focus', False)
        buttonStaff.connect("clicked", staffCommand)
        ButtonsTable.attach(buttonStaff, 1, 2, 1, 2, False, False)
        
        ## Fixed Right
        FixedRight = Gtk.Fixed()
        HBox.pack_start(FixedRight, True, True, 0)
        
        
        #Settings buttons
        settingButtons = Gtk.ButtonBox()
        settingButtons.set_property("name", "settingButtons")
        
        ##cog button
        image = Gtk.Image()
        image.set_from_file(get_theme_file_path('icons', 'settings'))
        cogButton = Gtk.Button()
        cogButton.set_size_request(64,64)
        cogButton.set_property("name", "cogButton")
        cogButton.set_property('can-focus', False)
        cogButton.connect("clicked", cogCommand)
        cogButton.add(image)
        settingButtons.pack_start(cogButton, False, False, 0)
        
        image = Gtk.Image()
        image.set_from_file(get_theme_file_path('icons', 'fire'))
        fireButton = Gtk.Button()
        fireButton.set_size_request(64,64)
        fireButton.set_property("name", "fireButton")
        fireButton.set_property('can-focus', False)
        fireButton.connect("clicked", fireCommand)
        fireButton.add(image)
        settingButtons.pack_start(fireButton, False, False, 0)
        self.VBox.pack_start(settingButtons, False, False, 0)
        
        
    def get_view(self):
        """Returns the view"""
        return self.VBox
        
    def set_visible(self, status):
        """Set the visible of the view"""
        self.VBox.set_visible(status)
        
    def get_visible(self):
        return self.VBox.get_visible()
