# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import Gtk, Gdk, GObject, GdkPixbuf, Pango
import cairo
import time
import pygame

from entrypoint.kiosk.Settings import get_data_file, get_theme_file_path
from entrypoint.kiosk.MainView import MainView
from entrypoint.kiosk.EntryView import EntryView
from entrypoint.kiosk.DobView import DobView
from entrypoint.kiosk.ListView import ListView
from entrypoint.kiosk.MessageView import MessageView
from entrypoint.kiosk.SettingMenuView import SettingMenuView
from entrypoint.kiosk.SettingView import SettingView
from entrypoint.kiosk.SignInVisitorController import SignInVisitorController
from entrypoint.kiosk.SignOutVisitorController import SignOutVisitorController
from entrypoint.kiosk.SettingController import SettingController
from entrypoint.kiosk.StaffController import StaffController
from entrypoint.kiosk.FireReport import FireReport
from entrypoint.common.Settings import Settings
from entrypoint.common.Key import Key
from entrypoint.common.VisitorManager import VisitorManager
from entrypoint.common.MemberManager import MemberManager

class MainWindow(Gtk.Window):

    def __init__(self):
        Gtk.Window.__init__(self, title="EntryPoint Kiosk")
        
        #Var
        self.leftActionHandlerId = None
        self.rightActionHandlerId = None
        self.key = None
        
        self.connect("realize", self.realize_cb)
        self.connect("delete-event", Gtk.main_quit)
        self.connect("key-press-event", self.on_window_key_press_event)
        
        self.set_icon_from_file(get_data_file("entrypoint-kiosk.png"))
        
        screen = Gdk.Screen.get_default()

        css_provider = Gtk.CssProvider()
        css_provider.load_from_path(get_theme_file_path('theme', 'gtk'))

        context = Gtk.StyleContext()
        context.add_provider_for_screen(screen, css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
        
        #Get Settings
        self.settings = Settings()
        
        #init pyGame
        pygame.init()
        
        self.setup_sound()
        
        ##contorrolers
        
        signInVisitorController = SignInVisitorController(self)
        signOutVisitorController = SignOutVisitorController(self)
        settingController = SettingController(self)
        staffController = StaffController(self)
        
        self.build_keyboard()
        self.eventBox = Gtk.EventBox()
        self.eventBox.set_property("name", "mainEventBox")
        self.eventBox.show()
        self.VBox = Gtk.VBox()
        self.VBox.show()
        self.eventBox.add(self.VBox)
         
        
        ### Date and Time
        self.DateTimeEventBox = Gtk.EventBox()
        self.DateTimeEventBox.set_property("name", "DateTimeEventBox")
        self.DateTimeBox = Gtk.HBox()
        self.DateTimeBox.show()
        self.DateTimeEventBox.add(self.DateTimeBox)
        self.lblDate = Gtk.Label()
        self.lblDate.set_justify(Gtk.Justification.LEFT)
        self.DateTimeBox.pack_start(self.lblDate, False, False, 0)
        self.lblTime = Gtk.Label()
        self.lblTime.set_justify(Gtk.Justification.RIGHT)
        self.DateTimeBox.pack_end(self.lblTime, False, False, 0)
        
        self.VBox.pack_start(self.DateTimeEventBox, False, False, 0)
        
        GObject.timeout_add(200, self.update_date_time)
        
        #Setup Views
        
        self.Main = MainView(signInVisitorController.start, signOutVisitorController.start, staffController.start, settingController.show_setting_menu, self.print_fire_report)
        self.VBox.pack_start(self.Main.get_view(), True, True, 0)
        
        self.listView = ListView()
        self.VBox.pack_start(self.listView.get_view(), True, True, 0)

        # Date of Birth View
        self.DobView = DobView(staffController.date_button)
        self.VBox.pack_start(self.DobView.get_view(), True, True, 0)
        
        ##Entry View
        self.EntryView = EntryView()
        self.VBox.pack_start(self.EntryView.get_view(), True, True, 0)
        self.selectedEntry = self.EntryView.entry
        
        ##Message View
        self.MessageView = MessageView()
        self.VBox.pack_start(self.MessageView.get_view(), True, True, 0)
        
        ##Setting Menu View
        self.SettingMenuView = SettingMenuView(settingController.show_setting, settingController.show_about,settingController.hide_setting_menu)
        self.VBox.pack_start(self.SettingMenuView.get_view(), True, True, 0)
        
        ##Setting View
        self.SettingView = SettingView(settingController.changed_button_scale, settingController.changed_sign_in_scale, settingController.select_label_printer, settingController.select_fire_printer, settingController.hide_setting_menu)
        self.VBox.pack_start(self.SettingView.get_view(), True, True, 0)
        
        #Action Buttons
        self.actionButtons = Gtk.ButtonBox()
        self.actionButtonLeft = Gtk.Button(label="Back")
        self.actionButtonLeft.set_size_request(150,65)
        self.actionButtonLeft.set_property('can-focus', False)
        self.actionButtons.add(self.actionButtonLeft)
        
        self.actionButtonRight = Gtk.Button(label="Next")
        self.actionButtonRight.set_size_request(150,65)
        self.actionButtonRight.set_property('can-focus', False)
        self.actionButtons.add(self.actionButtonRight)
        self.VBox.pack_start(self.actionButtons, False, False, 3)
        
        #Add Keyboard to Vbox
        self.VBox.pack_start(self.kb_eb, False, False, 0)
        
        self.add(self.eventBox)
        self.VBox.show()
    
    def realize_cb(self, widget):
        s = cairo.ImageSurface(cairo.FORMAT_A1, 1, 1)
        cursor_pixbuf = Gdk.pixbuf_get_from_surface(s, 0, 0, 1, 1)
        cursor = Gdk.Cursor.new_from_pixbuf(Gdk.Display.get_default(), \
                                    cursor_pixbuf, 0, 0)
        #widget.get_window().set_cursor(cursor)
        
        self.keyboard.set_visible(False)
        self.EntryView.set_visible(False)
        self.actionButtons.set_visible(False)
        self.MessageView.set_visible(False)
        self.SettingMenuView.set_visible(False)
        self.SettingView.set_visible(False)
        self.listView.set_visible(False)
        self.DobView.set_visible(False)
        pass
    
    def on_window_key_press_event(self, widget, data=None):
        if data.keyval == 65293:
            key = Key(key=self.key)
            if not key.get_key_type() == None:
                relObject = key.get_related_object()
                if relObject == None:
                    return
                    
                if key.get_key_type() == 'visitor':
                    relObject.sign_out()
                    status = False
                elif key.get_key_type() == 'member':
                    relObject.sign_in_out()
                    status = relObject.get_status()
                   
                if status:
                    self.signInSound.play()
                else:
                    self.signOutSound.play()
                
                if self.Main.get_visible():
                    if status:
                        self.MessageView.set_text("Thank you for signing In.", "Have a nice day!")
                    else:
                        self.MessageView.set_text("Thank you for signing Out.", "Have a nice day!")
                    
                    self.MessageView.set_visible(True)
                    self.Main.set_visible(False)
                    GObject.timeout_add(1500, self.reset)
            self.key = None
        elif len(Gdk.keyval_name(data.keyval)) == 1:
            if self.key != None:
                self.key = str(self.key) + str(Gdk.keyval_name(data.keyval))
            else:
                self.key = str(Gdk.keyval_name(data.keyval))
    
    def reset(self):
        self.MessageView.set_visible(False)
        self.Main.set_visible(True)
    
    def update_date_time(self):
        self.lblDate.set_text(time.strftime('%A %e %B %Y'))
        self.lblTime.set_text(time.strftime('%I:%M:%S %p'))
        return True
            
    def build_keyboard(self):
        self.kb_eb = Gtk.Alignment()
        self.kb_eb.set_property("name", "keyboard")    

        self.keyboard = Gtk.VBox()
        
        self.kb_eb.add(self.keyboard)
        
        ## Row 1
        kbRow1 = Gtk.HBox()
        
        ### Fixed Left
        kbFixed1L = Gtk.Fixed()
        kbRow1.pack_start(kbFixed1L, True, True, 0)
        
        ### Keys 1
        kbKeys1 = Gtk.HBox()
        
        #### Buttons
        self.kbButtons = {}
        for l in ["1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "Backspace"]:
            kbKeys1.pack_start(self.keyboard_button(l), False, False, 3)
        
        ###Keys 1 End
        kbRow1.pack_start(kbKeys1, False, False, 3)
        
        ### Fixed RightGtk.Button(label="Visitor Sign In")
        kbFixed1R = Gtk.Fixed()
        kbRow1.pack_start(kbFixed1R, True, True, 0)
        
        ## Row 1 End
        self.keyboard.pack_start(kbRow1, False, False, 0)
       
        ## Row 2
        kbRow2 = Gtk.HBox(spacing=3)
        
        ### Fixed Left
        kbFixed2L = Gtk.Fixed()
        kbRow2.pack_start(kbFixed2L, True, True, 0)
        
        ### Keys 2
        kbKeys2 = Gtk.HBox()
        
        #### Buttons
        for l in ["Q", "W", "E", "R", "T", "Y", "U", "I", "O", "P"]:
            kbKeys2.pack_start(self.keyboard_button(l), False, False, 3)
         
        ###Keys 2 End
        kbRow2.pack_start(kbKeys2, False, False, 3)
        
        ### Fixed Rightaction_buttons_reconnect
        kbFixed2R = Gtk.Fixed()
        kbRow2.pack_start(kbFixed2R, True, True, 0)
        
        ## Row 2 End
        self.keyboard.pack_start(kbRow2, False, False, 3)
        
        ## Row 3
        kbRow3 = Gtk.HBox()
        
        ### Fixed Left
        kbFixed3L = Gtk.Fixed()
        kbRow3.pack_start(kbFixed3L, True, True, 0)
        
        ### Keys 3
        kbKeys3 = Gtk.HBox()
        
        #### Buttons
        for l in ["A", "S", "D", "F", "G", "H", "J", "K", "L"]:
            kbKeys3.pack_start(self.keyboard_button(l), False, False, 3)
        
        ###Keys 3 End
        kbRow3.pack_start(kbKeys3, False, False, 3)
        
        ### Fixed Right
        kbFixed3R = Gtk.Fixed()
        kbRow3.pack_start(kbFixed3R, True, True, 0)
        
        ## Row 3 End
        self.keyboard.pack_start(kbRow3, False, False, 0)
        
        ## Row 4
        kbRow4 = Gtk.HBox()
        
        ### Fixed Left
        kbFixed4L = Gtk.Fixed()
        kbRow4.pack_start(kbFixed4L, True, True, 0)
        
        ### Keys 4
        kbKeys4 = Gtk.HBox()
        
        #### Buttons
        for l in ["Z", "X", "C", "V", "B", "N", "M", ".", "<", ">"]:
            kbKeys4.pack_start(self.keyboard_button(l), False, False, 3)
        
        ### Keys 4 End
        kbRow4.pack_start(kbKeys4, False, False, 3)
        
        ### Fixed Right
        kbFixed4R = Gtk.Fixed()

        kbRow4.pack_start(kbFixed4R, True, True, 0)
        
        ## Row 4 End
        self.keyboard.pack_start(kbRow4, False, False, 3)
        
        ## Row 5
        kbRow5 = Gtk.HBox()
        
        ### Fixed Left
        kbFixed5L = Gtk.Fixed()
        kbRow5.pack_start(kbFixed5L, True, True, 0)
        
        ### Keys 5
        kbKeys5 = Gtk.HBox()
        
        #### Button
        kbKeys5.pack_start(self.keyboard_button("Space"), False, False, 3)
        
        ### Keys 5 End
        kbRow5.pack_start(kbKeys5, False, False, 3)
  
        ### Fixed Right
        kbFixed5R = Gtk.Fixed()

        kbRow5.pack_start(kbFixed5R, True, True, 0)
        
        ## Row 5 End
        self.keyboard.pack_start(kbRow5, False, False, 0)
        
    def keyboard_button(self, letter):
        if letter == "<":
            self.kbButtons[letter] = Gtk.Button()
            image = Gtk.Image()
            image.set_from_file(get_theme_file_path('icons', 'left'))
            self.kbButtons[letter].add(image)
            self.kbButtons[letter].connect("clicked", self.on_kbButton_left_clicked)
        elif letter == ">":
            self.kbButtons[letter] = Gtk.Button()
            image = Gtk.Image()
            image.set_from_file(get_theme_file_path('icons', 'right'))
            self.kbButtons[letter].add(image)
            self.kbButtons[letter].connect("clicked", self.on_kbButton_right_clicked)
        else:
            self.kbButtons[letter] = Gtk.Button(label=letter)
            self.kbButtons[letter].connect("clicked", self.on_kbButtons_clicked)
        
        if(letter == "Backspace"):
            self.kbButtons[letter].set_size_request(145,75)
        elif(letter == "Space"):
            self.kbButtons[letter].set_size_request(350,75)
        else:
            self.kbButtons[letter].set_size_request(75,75)
        
        self.kbButtons[letter].set_property('can-focus', False)
        return self.kbButtons[letter]
    
    def on_kbButton_left_clicked(self, widget):
        #get the position of the current cursor
        pos = self.selectedEntry.get_position()
        
        self.buttonSound.play()
        self.selectedEntry.set_position(pos-1)

    def on_kbButton_right_clicked(self, widget):
        #get the position of the current cursor
        pos = self.selectedEntry.get_position()
        
        self.buttonSound.play()
        self.selectedEntry.set_position(pos+1)

    def on_kbButtons_clicked(self, widget):
        self.buttonSound.play()
        
        letter = widget.get_label()
        
        #get the position of the current cursor
        pos = self.selectedEntry.get_position()
    
        #get the current text string
        text = self.selectedEntry.get_text()
        
        if letter == "Space":
            letter = " "
        
        if letter == "Backspace":
            self.selectedEntry.set_text(text[0:pos-1]+text[pos:len(text)])
            self.selectedEntry.set_position(pos-1)  
        
        else:
            self.selectedEntry.set_text(text[0:pos]+letter+text[pos:len(text)])
            self.selectedEntry.set_position(pos+1)
            
        self.selectedEntry.grab_focus()
        
    def action_buttons_reconnect(self, button, handler, *args):
        if button == "left":
            if not self.leftActionHandlerId == None:
                self.actionButtonLeft.disconnect(self.leftActionHandlerId)
            self.leftActionHandlerId = self.actionButtonLeft.connect("clicked", handler, *args)
        elif button == "right":
            if not self.rightActionHandlerId == None:
                self.actionButtonRight.disconnect(self.rightActionHandlerId)
            self.rightActionHandlerId = self.actionButtonRight.connect("clicked", handler, *args)
            
    def setup_sound(self):
        self.buttonSound = pygame.mixer.Sound(get_theme_file_path('sounds', 'button-press'))
        self.buttonSound.set_volume(float(self.settings.get_item('sounds', 'volume-button')))
        
        self.signInSound = pygame.mixer.Sound(get_theme_file_path('sounds', 'signin'))
        self.signInSound.set_volume(float(self.settings.get_item('sounds', 'volume-signinout')))
        
        self.signOutSound = pygame.mixer.Sound(get_theme_file_path('sounds', 'signout'))
        self.signOutSound.set_volume(float(self.settings.get_item('sounds', 'volume-signinout')))
        
    def print_fire_report(self, widget):
        data = [['Name', 'Company', 'Checked']]
        visitors = VisitorManager("`time_out` IS NULL", 'name').get_visitors()
        for vid in visitors:
            data.append([visitors[vid].get_name(), visitors[vid].get_company(), ''])
            
        members = MemberManager(None,'last name').get_members_in()
        for mid in members:
            data.append([members[mid].get_name(), 'Staff', ''])

        FireReport(data)
    
    
