# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import cups
import time
from gi.repository import Gtk

from entrypoint.kiosk.Settings import get_version

class SettingController():
    def __init__(self, window,):
        self.window = window
        self.currentButtonVol = 0
        self.currentSignInVol = 0
        
    def show_setting_menu(self, widget=None):
        #play button sound
        self.window.buttonSound.play()
        
        #Show setting menu View
        self.window.SettingMenuView.set_visible(True)
        
        #Hide main view
        self.window.Main.set_visible(False)
        
        #Hide List View
        self.window.listView.set_visible(False)
        
        #Hide Action Buttons
        self.window.actionButtons.set_visible(False)
        
    def hide_setting_menu(self, widget):
        #play button sound
        self.window.buttonSound.play()
        
        #Write settings
        self.window.settings.write()
        
        #Hide setting menu View
        self.window.SettingMenuView.set_visible(False)
        
        #hide setting View
        self.window.SettingView.set_visible(False)
        
        #Hide List View
        self.window.listView.set_visible(False)
        
        #Show main view
        self.window.Main.set_visible(True)
        
    def show_about(self, widget):
        #play button sound
        self.window.buttonSound.play()
        
        dlg = Gtk.AboutDialog(title="EntryPoint Kiosk")
        dlg.set_name("EntryPoint Kiosk")
        dlg.set_program_name("EntryPoint Kiosk")
        dlg.set_comments("A Visitors book system for Schools.")
        dlg.set_version(get_version())
        dlg.set_copyright("Copyright (C) 2012 Samuel Taylor")
        dlg.set_authors(["Samuel Taylor <samtaylor.uk@gmail.com> (Main Programmer)"])
        dlg.set_website("http://www.entrypoint.org.uk")
        dlg.connect("response", self.hide_about)
        dlg.show()
        
    def hide_about(self, widget, res):
        #TODO: Change for GTK3
        #if res == Gtk.RESPONSE_CANCEL:
        widget.hide()
        
    def show_setting(self, widget=None):
        #play button sound
        self.window.buttonSound.play()
        
        #Set current sound
        self.window.SettingView.set_volume(self.window.settings.get_itemfloat('sounds', 'volume-button')*10, float(self.window.settings.get_item('sounds', 'volume-signinout'))*10)
        
        #Show setting View
        self.window.SettingView.set_visible(True)
        
        #Hide setting menu View
        self.window.SettingMenuView.set_visible(False)
        
        #Hide List View
        self.window.listView.set_visible(False)
        
        #Hide Action Buttons
        self.window.actionButtons.set_visible(False)
        
    def changed_button_scale(self, widget):
        self.currentButtonVol
        volume = float(widget.get_value() / 10)
        self.window.settings.set_item('sounds', 'volume-button', str(volume))
        self.window.buttonSound.set_volume(volume)
        
        #play button sound
        if not self.currentButtonVol == 0:
            if (self.currentButtonVol + 0.08) <= volume or (self.currentButtonVol - 0.08) >= volume:
                self.window.buttonSound.play()
                self.currentButtonVol = volume
        else:
            self.currentButtonVol = volume
        
        
    def changed_sign_in_scale(self, widget):
        self.currentSignInVol
        volume = float(widget.get_value() / 10)
        self.window.settings.set_item('sounds', 'volume-signinout', str(volume))
        self.window.signInSound.set_volume(volume)
        self.window.signOutSound.set_volume(volume)
        
        #play button sound
        if not self.currentSignInVol == 0:
            if (self.currentSignInVol + 0.08) <= volume or (self.currentSignInVol - 0.08) >= volume:
                self.window.signInSound.play()
                self.currentSignInVol = volume
        else:
            self.currentSignInVol = volume
        
    def select_label_printer(self, widget):
        self.window.listView.set_question("Please choose the label printer from the list below.")
        
        self.window.listView.set_list(bool, str)
        
        data = (("", True, 'radio'),
                ("Printer", True, 'text'),
               )
        self.window.listView.set_columns(data)
        
        currentPrinter = self.window.settings.get_item('printers', 'label-printer')
        
        con = cups.Connection() 
        
        for printer in con.getPrinters():
            if printer == currentPrinter:
                status = True
            else:
                status = False
            self.window.listView.list_append([status, printer])
            
        #play button sound
        self.window.buttonSound.play()
        
        #Hide setting menu View
        self.window.SettingMenuView.set_visible(False)
        
        #Hide setting View
        self.window.SettingView.set_visible(False)
        
        #Hide main view
        self.window.Main.set_visible(False)
        
        #Show List View
        self.window.listView.set_visible(True)
        
        #Setup action buttons
        self.window.actionButtonLeft.set_label("Cancel")
        self.window.actionButtonLeft.set_visible(True)
        self.window.action_buttons_reconnect("left", self.show_setting)
        self.window.actionButtonRight.set_visible(True)
        self.window.action_buttons_reconnect("right", self.save_label_printer)
        self.window.actionButtonRight.set_label("Save")
        self.window.actionButtons.set_visible(True)
        
    def save_label_printer(self, widget):
        self.window.settings.remove_item('printers', 'label-printer')
    
        for row in self.window.listView.list:
            if row[0]:
                self.window.settings.set_item('printers', 'label-printer', row[1])
                break
        
        #Write settings
        self.window.settings.write()
                
        self.show_setting()
        
        #play button sound
        self.window.buttonSound.play()
            
    def select_fire_printer(self, widget):
        self.window.listView.set_question("Please choose up to 5 fire printers from the list below.")
        
        self.window.listView.set_list(bool, str)
        
        data = (("", True, 'checkbox'),
                ("Printer", True, 'text'),
               )
        self.window.listView.set_columns(data)
        
        currentPrinters = []
        
        con = cups.Connection()
        i =1
        while i < 6:
            printer = self.window.settings.get_item('printers', 'fire-printer-'+str(i))
            if printer == False:
                pass
            else:
                currentPrinters.append(printer)
            i+=1
        
        for printer in con.getPrinters():
            if printer in currentPrinters:
                status = True
            else:
                status = False
            self.window.listView.list_append([status, printer])
            
        #play button sound
        self.window.buttonSound.play()
        
        #Hide setting menu View
        self.window.SettingMenuView.set_visible(False)
        
        #Hide setting View        
        self.window.SettingView.set_visible(False)
        
        #Show List View
        self.window.listView.set_visible(True)
        
        #Setup action buttons
        self.window.actionButtonLeft.set_label("Cancel")
        self.window.actionButtonLeft.set_visible(True)
        self.window.action_buttons_reconnect("left", self.show_setting)
        self.window.actionButtonRight.set_visible(True)
        self.window.action_buttons_reconnect("right", self.save_fire_printer)
        self.window.actionButtonRight.set_label("Save")
        self.window.actionButtons.set_visible(True)
        
    def save_fire_printer(self, widget):
        i =1
        while i < 6:
            self.window.settings.remove_item('printers', 'fire-printer-'+str(i))
            i+=1
        
        i = 1
        for row in self.window.listView.list:
            if row[0]:
                self.window.settings.set_item('printers', 'fire-printer-'+str(i), row[1])
                i+=1
                if i == 6:
                    break
        
        #Write settings
        self.window.settings.write()
                
        self.show_setting()
        
        #play button sound
        self.window.buttonSound.play()
        self.window.SettingView.set_visible(False)
        
        #Hide main view
        self.window.Main.set_visible(False)
        
        #Show List View
        self.window.listView.set_visible(True)
        
        #Setup action buttons
        self.window.actionButtonLeft.set_label("Cancel")
        self.window.actionButtonLeft.set_visible(True)
        self.window.action_buttons_reconnect("left", self.show_setting)
        self.window.actionButtonRight.set_visible(True)
        self.window.action_buttons_reconnect("right", self.save_fire_printer)
        self.window.actionButtonRight.set_label("Save")
        self.window.actionButtons.set_visible(True)
        
    def save_fire_printer(self, widget):
        i =1
        while i < 6:
            self.window.settings.remove_item('printers', 'fire-printer-'+str(i))
            i+=1
        
        i = 1
        for row in self.window.listView.list:
            if row[0]:
                self.window.settings.set_item('printers', 'fire-printer-'+str(i), row[1])
                i+=1
                if i == 6:
                    break
        
        #Write settings
        self.window.settings.write()
                
        self.show_setting()
        
        #play button sound
        self.window.buttonSound.play()
            
            
            
            
            
