# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import sys 
import ConfigParser

from entrypoint.kiosk import __entrypoint_kiosk_data_directory__, __license__, __version__
from entrypoint.common.Settings import Settings

class project_path_not_found(Exception):
    """Raised when we can't find the project directory."""


def get_data_file(*path_segments):
    """Get the full path to a data file.

    Returns the path to a file underneath the data directory (as defined by
    `get_data_path`). Equivalent to os.path.join(get_data_path(),
    *path_segments).
    """
    return os.path.join(get_data_path(), *path_segments)


def get_data_path():
    """Retrieve visitors-book data path

    This path is by default <entrypoint.kiosk_path>/../../data/ in trunk
    and /usr/share/entrypoint-kiosk in an installed version but this path
    is specified at installation time.
    """

    # Get pathname absolute or relative.
    path = os.path.join(
        os.path.dirname(__file__), __entrypoint_kiosk_data_directory__)

    abs_data_path = os.path.abspath(path)
    if not os.path.exists(abs_data_path):
        appdir = os.path.dirname(sys.argv[0])
        data_file_name = os.path.join(appdir, "data")
        if os.path.exists(data_file_name):
            return data_file_name
        else:
            raise project_path_not_found

    return abs_data_path


def get_version():
    return __version__
    
def get_theme_file_path(itemType, item):
    """Returns absolute path for a selected theme file."""
    theme = Settings().get_item('general', 'theme')
    config = ConfigParser.ConfigParser()
    config.read(get_data_file('themes', theme, 'theme.cfg'))
    
    return get_data_file('themes', theme, config.get(itemType, item))
