# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2011 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import GObject

from entrypoint.kiosk.Helpers import print_visitor_pass
from entrypoint.common.Visitor import Visitor

class SignInVisitorController():
    
    def __init__(self, window,):
        self.window = window
        
    def start(self, widget):
        #play button sound
        self.window.buttonSound.play()

        #setup var
        self.name = ""
        self.company = ""
        self.carReg = ""
        self.reason = ""
        
        #Setup question
        self.question("name")
        
        #Show EntryView
        self.window.EntryView.set_visible(True)
        
        #show keyboard
        self.window.keyboard.set_visible(True)
        
        #show action buttons
        self.window.actionButtons.set_visible(True)
        
        #Hide main view
        self.window.Main.set_visible(False)   
    
    def next(self, widget, question, questionBefore=None):
        if not question == "finish":
            self.window.buttonSound.play()
        if question == "reset":
            self.reset()
        else:
            self.question(question, questionBefore)
        
    def question(self, question, questionBefore=None, error=None):
        
        #Save last question
        if questionBefore == "name":
            self.name = self.window.EntryView.get_text()
        elif questionBefore == "company":
            self.company = self.window.EntryView.get_text()
        elif questionBefore == "carReg":
            self.carReg = self.window.EntryView.get_text()
        elif questionBefore == "reason":
            self.reason = self.window.EntryView.get_text()
        
        #setup and show entryview
        ##Setup view for name question
        if question == "name":
            self.window.EntryView.set_question("Please enter your full name using the keyboard below.")
            self.window.EntryView.set_text(self.name)
            self.window.action_buttons_reconnect("left", self.next, "reset")
            self.window.actionButtonLeft.set_label("Cancel")
            self.window.action_buttons_reconnect("right", self.next, "company","name")
            self.window.actionButtonRight.set_label("Next")
        
        ##Setup view for company question
        elif question == "company":
            self.window.EntryView.set_question("Please enter your company using the keyboard below. If you are a parent please leave blank.")
            self.window.EntryView.set_text(self.company)
            self.window.action_buttons_reconnect("left", self.next, "name", "company")
            self.window.actionButtonLeft.set_label("Back")
            self.window.action_buttons_reconnect("right", self.next, "carReg", "company")
            self.window.actionButtonRight.set_label("Next")
        
        ##Setup view for car reg question
        elif question == "carReg":
            self.window.EntryView.set_question("Please enter your car registration using the keyboard below.")
            self.window.EntryView.set_text(self.carReg)
            self.window.action_buttons_reconnect("left", self.next, "company", "carReg")
            self.window.actionButtonLeft.set_label("Back")
            self.window.action_buttons_reconnect("right", self.next, "reason", "carReg")
            self.window.actionButtonRight.set_label("Next")
        
        ##Setup view for reason question
        elif question == "reason":
            self.window.EntryView.set_question("Please enter your reason for your visitor using the keyboard below.")
            self.window.EntryView.set_text(self.reason)
            self.window.action_buttons_reconnect("left", self.next, "carReg", "reason")
            self.window.actionButtonLeft.set_label("Back")
            self.window.action_buttons_reconnect("right", self.next, "finish", "reason")
            self.window.actionButtonRight.set_label("Finish")
            
        elif question == "finish":
            self.finish()
            
    def finish(self):
        #Add infomation to database
        visitor = Visitor(name=self.name, company=self.company, carRegistration=self.carReg, reason=self.reason)
    
        #Print Visitors badge
        print_visitor_pass(visitor.get_name(), visitor.get_company(), visitor.get_reason(), visitor.get_key(), visitor.get_time_in().strftime("%d/%m/%Y %H:%M"))
        
        #Play Sign in sound
        self.window.signInSound.play()
        
        #setup and show Message View
        self.window.MessageView.set_text("Thank you for signing in. Please wait for the receptionist.", "Have a nice day!")
        self.window.MessageView.set_visible(True)
        
        #hide EntryView
        self.window.EntryView.set_visible(False)
        
        #hide keyboard
        self.window.keyboard.set_visible(False)
        
        #hide action buttons
        self.window.actionButtons.set_visible(False)
        
        GObject.timeout_add(1500, self.reset)
    
    def reset(self):
        #hide Message View
        self.window.MessageView.set_visible(False)
        
        #hide EntryView
        self.window.EntryView.set_visible(False)
        
        #hide keyboard
        self.window.keyboard.set_visible(False)
        
        #hide action buttons
        self.window.actionButtons.set_visible(False)
        
        #show main view
        self.window.Main.set_visible(True)
        
