# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2011 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import Gtk
from gi.repository import GObject

from entrypoint.common.VisitorManager import VisitorManager

class SignOutVisitorController:
    def __init__(self, window,):
        self.window = window
        
    def start(self, widget):
        #play button sound
        self.window.buttonSound.play()
        
        #Setup List coloums
        self.window.listView.set_list(int, str, str, str)
        
        data = (("ID", False, 'text'),
                ("Name", True, 'text'),
                ("Company", True, 'text'),
                ("Car Registration", True, 'text'),
               )
        self.window.listView.set_columns(data)
        
        self.window.listView.set_question("Please select your name from the list below and press the sign out button")
        
        self.visitors = VisitorManager("`time_out` IS NULL").get_visitors()
        for vid in self.visitors:
            self.window.listView.list_append([int(vid), self.visitors[vid].get_name(), self.visitors[vid].get_company(), self.visitors[vid].get_car_registration()])
        
        #show action buttons
        self.window.actionButtons.set_visible(True)
        
        #Setup action buttons
        self.window.actionButtonLeft.set_label("Cancel")
        self.window.action_buttons_reconnect("left", self.back)
        self.window.action_buttons_reconnect("right", self.sign_out,)
        self.window.actionButtonRight.set_label("Sign Out")
        
        #Show List View
        self.window.listView.set_visible(True)
        
        #Hide main view
        self.window.Main.set_visible(False)
        
    def sign_out(self, widget):
        selection = self.window.listView.TreeView.get_selection()
        selection.set_mode(Gtk.SelectionMode.SINGLE)
        treeModel, treeIter = selection.get_selected()
        vid = treeModel.get_value(treeIter, 0)
        self.visitors[vid].sign_out()
        
        #Play Sign in sound
        self.window.signOutSound.play()
        
        #setup and show Message View
        self.window.MessageView.set_text("Thank you for signing Out.", "Have a nice day!")
        self.window.MessageView.set_visible(True)
        
        #hide List View
        self.window.listView.set_visible(False)        

        #hide action buttons
        self.window.actionButtons.set_visible(False)
        
        GObject.timeout_add(1500, self.reset)
            
    def back(self, widget):
        self.window.buttonSound.play()
        self.reset()
    
    def reset(self):
        #hide Message View
        self.window.MessageView.set_visible(False)
        
        #hide List View
        self.window.listView.set_visible(False)
        
        #hide action buttons
        self.window.actionButtons.set_visible(False)
        
        #show main view
        self.window.Main.set_visible(True)
