# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# This file is part of EntryPoint
### BEGIN LICENSE
# Copyright (C) 2012 Samuel Taylor <samtaylor.uk@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import GObject

from entrypoint.common.Member import Member
from entrypoint.common.MemberManager import MemberManager

class StaffController():
    def __init__(self, window):
         self.window = window
         
    def start(self, widget=None):
        #play button sound
        self.window.buttonSound.play()
        
        #Show DOB View
        self.window.DobView.set_visible(True)
        
        #Hide main view
        self.window.Main.set_visible(False)
        
        #show action buttons
        self.window.actionButtons.set_visible(True)
        #Setup action buttons
        self.window.actionButtonLeft.set_label("Cancel")
        self.window.action_buttons_reconnect("left", self.reset)
        self.window.actionButtonRight.set_visible(False)
        
        
    
    def date_button(self, widget):
        #play button sound
        self.window.buttonSound.play()
        
        if len(widget.get_label()) > 1:
            day = widget.get_label()
        else:
            day = str('0') + widget.get_label() 
        
        self.window.listView.set_question("Please select your name from the list below and press the sign in/out button")
        
        self.window.listView.set_list(int, str, str, str)
        
        data = (("ID", False, 'text'),
                ("First Name", True, 'text'),
                ("Last Name", True, 'text'),
                ("Status", True, 'text'),
               )
        self.window.listView.set_columns(data)
        
        members = MemberManager("`active` = 1 AND DATE_FORMAT(`date_of_birth`,'%d') = "+str(day)).get_members()
        for mid in members:
            if members[mid].get_status():
                status = "In"
            else:
                status = "Out"
                
            self.window.listView.list_append([int(mid),members[mid].get_first_name(), members[mid].get_last_name(), status])
            
        #Show List View
        self.window.listView.set_visible(True)
        
        #Hide DOB View
        self.window.DobView.set_visible(False)
        
        #Setup action buttons
        self.window.actionButtonLeft.set_label("Back")
        self.window.action_buttons_reconnect("left", self.button_back)
        self.window.actionButtonRight.set_visible(True)
        self.window.action_buttons_reconnect("right", self.sign_in_out,)
        self.window.actionButtonRight.set_label("Sign In/Out")

    
    def sign_in_out(self, widget):
        model, treeiter = self.window.listView.get_selected()
        member = Member(mid=model[treeiter][0])
        if member.get_status():
            #Play Sign out sound
            self.window.signOutSound.play()
            self.window.MessageView.set_text("Thank you for signing Out.", "Have a nice day!")
        else:
            #Play Sign in sound
            self.window.signInSound.play()
            self.window.MessageView.set_text("Thank you for signing In.", "Have a nice day!")
        
        member.sign_in_out()
        
        self.window.MessageView.set_visible(True)
        
        #hide List View
        self.window.listView.set_visible(False)        

        #hide action buttons
        self.window.actionButtons.set_visible(False)
        
        GObject.timeout_add(1500, self.reset)

    def button_back(self, widget):
        self.window.buttonSound.play()
        self.reset()
        self.start()

    def reset(self, widget=None):
        #Hide DOB View
        self.window.DobView.set_visible(False)
        
        #Hide List View
        self.window.listView.set_visible(False)
        
        #Show main view
        self.window.Main.set_visible(True)
        
        self.window.actionButtonRight.set_visible(True)
        
        #hide action buttons
        self.window.actionButtons.set_visible(False)
        
        self.window.MessageView.set_visible(False)
    
        
        
